function varargout = aplicacao_teste(varargin)
% APLICACAO_TESTE M-file for aplicacao_teste.fig
%      APLICACAO_TESTE, by itself, creates a new APLICACAO_TESTE or raises the existing
%      singleton*.
%
%      H = APLICACAO_TESTE returns the handle to a new APLICACAO_TESTE or the handle to
%      the existing singleton*.
%
%      APLICACAO_TESTE('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in APLICACAO_TESTE.M with the given input arguments.
%
%      APLICACAO_TESTE('Property','Value',...) creates a new APLICACAO_TESTE or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before aplicacao_teste_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to aplicacao_teste_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help aplicacao_teste

% Last Modified by GUIDE v2.5 07-Mar-2007 01:02:37
uiwait;
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @aplicacao_teste_OpeningFcn, ...
                   'gui_OutputFcn',  @aplicacao_teste_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before aplicacao_teste is made visible.
function aplicacao_teste_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to aplicacao_teste (see VARARGIN)

% Choose default command line output for aplicacao_teste
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);
uiwait;
% UIWAIT makes aplicacao_teste wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = aplicacao_teste_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
handles.output = 'yes';
guidata(hObject, handles);
uiresume;
